(load "setenv")
;;(trace unix:unix-exit :break t)
(in-package "USER")

#+nil
(setf *debugger-hook* #'(lambda (&rest stuff) 
                          (format t "~&~%~%Quiting because of: ~A~%" stuff)
			  #+nil
			  (ext:quit t)
			  (unix:unix-exit 1))
      *interactive* nil			; try to ask about errors
      *gc-verbose* nil			; give GC messages
      *compile-verbose* nil		; be chatty
      *compile-print* nil		; tell where the compiler is
      *compile-progress* nil)		; tell what the compiler is doing

(setf lisp::*genesis-core-name* "target:lisp/junk.core")
(load "target:code/exports")
(load "target:tools/setup")
(load "target:tools/worldcom")
(load "target:tools/comcom")   
(load "target:tools/pclcom")		; Rebuild pcl. See note.

(setf *interactive* t			; try to ask about errors
      *gc-verbose* t			; give GC messages
      *compile-verbose* t		; be chatty
      *compile-print* t			; tell where the compiler is
      *compile-progress* nil)		; tell what the compiler is doing
(load "target:tools/worldbuild")
(quit)
